import { CustomError } from '../errors/custom.error';
/**
 * Custom error type to handle API specific errors.
 */
export declare class DialogError extends CustomError {
    innerError?: Error;
    /**
     * @constructor
     *
     * @param message Error message to be propagated.
     * @param state OAuth state if available.
    */
    constructor(message: string, innerError?: Error);
}
/**
 * An optimized size object computed based on Screen Height & Screen Width
 */
export interface IDialogSize {
    width: number;
    width$: number;
    height: number;
    height$: number;
}
export declare class Dialog<T> {
    url: string;
    useTeamsDialog: boolean;
    /**
     * @constructor
     *
     * @param url Url to be opened in the dialog.
     * @param width Width of the dialog.
     * @param height Height of the dialog.
    */
    constructor(url?: string, width?: number, height?: number, useTeamsDialog?: boolean);
    private readonly _windowFeatures;
    private static readonly key;
    private _result;
    get result(): Promise<T>;
    size: IDialogSize;
    private _addinDialog;
    private _teamsDialog;
    private _webDialog;
    private _pollLocalStorageForToken;
    /**
     * Close any open dialog by providing an optional message.
     * If more than one dialogs are attempted to be opened
     * an exception will be created.
     */
    static close(message?: any, useTeamsDialog?: boolean): void;
    private _optimizeSize;
    private _maxSize;
    private _percentage;
    private _safeParse;
}
