import { CustomError } from '../errors/custom.error';
/**
 * Constant strings for the host types
 */
export declare const HostType: {
    WEB: string;
    ACCESS: string;
    EXCEL: string;
    ONENOTE: string;
    OUTLOOK: string;
    POWERPOINT: string;
    PROJECT: string;
    WORD: string;
};
/**
 * Constant strings for the host platforms
 */
export declare const PlatformType: {
    IOS: string;
    MAC: string;
    OFFICE_ONLINE: string;
    PC: string;
};
/**
 * Helper exposing useful Utilities for Office-Add-ins.
 */
export declare class Utilities {
    /**
     * A promise based helper for Office initialize.
     * If Office.js was found, the 'initialize' event is waited for and
     * the promise is resolved with the right reason.
     *
     * Else the application starts as a web application.
     */
    static initialize(): Promise<string>;
    static get host(): string;
    static get platform(): string;
    /**
     * Utility to check if the code is running inside of an add-in.
     */
    static get isAddin(): boolean;
    /**
     * Utility to check if the browser is IE11 or Edge.
     */
    static get isIEOrEdge(): boolean;
    /**
     * Utility to generate crypto safe random numbers
     */
    static generateCryptoSafeRandom(): number;
    /**
     * Utility to print prettified errors.
     * If multiple parameters are sent then it just logs them instead.
     */
    static log(exception: Error | CustomError | string, extras?: any, ...args: any[]): void;
}
