export interface IMessageBannerParams {
    title?: string;
    message?: string;
    type: 'default' | 'success' | 'error' | 'warning' | 'severe-warning';
    details?: string;
}
export declare class UI {
    /** Shows a basic notification at the top of the page
      * @param message - body of the notification
      */
    static notify(message: string): any;
    /** Shows a basic notification with a custom title at the top of the page
     * @param message - body of the notification
     * @param title - title of the notification
     */
    static notify(message: string, title: string): any;
    /** Shows a basic notification at the top of the page, with a background color set based on the type parameter
     * @param message - body of the notification
     * @param title - title of the notification
     * @param type - type of the notification - see https://dev.office.com/fabric-js/Components/MessageBar/MessageBar.html#Variants
     */
    static notify(message: string, title: string, type: 'default' | 'success' | 'error' | 'warning' | 'severe-warning'): any;
    /** Shows a basic error notification at the top of the page
     * @param error - Error object
     */
    static notify(error: Error): any;
    /** Shows a basic error notification with a custom title at the top of the page
     * @param title - Title, bolded
     * @param error - Error object
     */
    static notify(error: Error, title: string): any;
    /** Shows a basic notification at the top of the page
     * @param message - The body of the notification
     */
    static notify(message: any): any;
    /** Shows a basic notification with a custom title at the top of the page
     * @param message - body of the notification
     * @param title - title of the notification
     */
    static notify(message: any, title: string): any;
    /** Shows a basic notification at the top of the page, with a background color set based on the type parameter
     * @param message - body of the notification
     * @param title - title of the notification
     * @param type - type of the notification - see https://dev.office.com/fabric-js/Components/MessageBar/MessageBar.html#Variants
     */
    static notify(message: any, title: string, type: 'default' | 'success' | 'error' | 'warning' | 'severe-warning'): any;
}
export declare function _parseNotificationParams(params: any[]): IMessageBannerParams;
